@@ -20,13 +20,13 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
-class MStarDictConf {
+class Conf {
   private:
     GConfClient *gconf_client;
 
   public:
-    MStarDictConf();
-    ~MStarDictConf();
+    Conf();
+    ~Conf();
 
     bool GetStringList(const gchar *key,
 		       std::list < std::string > &list);
